# {{ project_name }} Requirements
# Generated by ABI-Core CLI

# ============================================
# CORE DEPENDENCIES (Minimal)
# ============================================

# Core Framework
abi-core-ai>=1.7.1
fastapi>=0.135.0
uvicorn[standard]>=0.42.0
pydantic>=2.12.0

# HTTP Client
httpx>=0.28.0

# Note: Additional dependencies are managed by individual services
# - Semantic Layer has its own requirements.txt
# - Guardian has its own requirements.txt
# - Agents have their own requirements.txt